summaryrefslogtreecommitdiffstats
path: root/parts/filecreate/fctemplateeditbase.ui.h
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filecreate/fctemplateeditbase.ui.h')
-rw-r--r--parts/filecreate/fctemplateeditbase.ui.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/parts/filecreate/fctemplateeditbase.ui.h b/parts/filecreate/fctemplateeditbase.ui.h
index f4fcfa05..5750f988 100644
--- a/parts/filecreate/fctemplateeditbase.ui.h
+++ b/parts/filecreate/fctemplateeditbase.ui.h
@@ -12,7 +12,7 @@
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/
@@ -22,5 +22,5 @@
void FCTemplateEditBase::init()
{
- templatename_edit->setValidator(new TQRegExpValidator(TQRegExp("^\\S*$"), this));
+ templatename_edit->setValidator(new TQRegExpValidator(TQRegExp("^\\S*$"), TQT_TQOBJECT(this)));
}
@@ -12,7 +12,7 @@
**
** If you wish to add, delete or rename functions or slots use
-** Qt Designer which will update this file, preserving your code. Create an
+** TQt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.